@@ -64,11 +64,18 @@ def parse_args():
     )
     parser.add_argument(
         "command",
-        choices=["get-devices", "get-details", "install", "refresh"],
+        choices=[
+            "get-devices",
+            "get-details",
+            "install",
+            "refresh",
+            "get-bios-setting",
+        ],
         help="What to do",
     )
     parser.add_argument("cab", nargs="?", help="CAB file")
     parser.add_argument("deviceid", nargs="?", help="DeviceID to operate on(optional)")
+    parser.add_argument("--setting", help="BIOS setting to operate on(optional)")
     args = parser.parse_args()
     return args
 
@@ -76,7 +83,7 @@ def parse_args():
 def refresh(client):
     """Uses fwupd client to refresh metadata"""
     remotes = client.get_remotes()
-    client.set_user_agent_for_package("simple_client", "1.8.3")
+    client.set_user_agent_for_package("simple_client", "1.8.10")
     for remote in remotes:
         if not remote.get_enabled():
             continue
@@ -99,6 +106,14 @@ def get_details(client, cab):
         print(device.to_string())
 
 
+def get_bios_settings(client, setting):
+    """Use fwupd client to get BIOS settings"""
+    settings = client.get_bios_settings()
+    for i in settings:
+        if not setting or setting == i.get_name() or setting == i.get_id():
+            print(i.to_string())
+
+
 def status_changed(client, spec, progress):  # pylint: disable=unused-argument
     """Signal emitted by fwupd daemon indicating status changed"""
     progress.status_changed(
@@ -188,3 +203,5 @@ if __name__ == "__main__":
     elif ARGS.command == "install":
         check_exists(ARGS.cab)
         install(CLIENT, ARGS.cab, ARGS.deviceid, ARGS.allow_older, ARGS.allow_reinstall)
+    elif ARGS.command == "get-bios-setting":
+        get_bios_settings(CLIENT, ARGS.setting)
